# BillRunType

Type of the bill run. * `Regular` - The normal bill run that produces invoices. * `CatchUp` - A catch up bill run that does not generate any invoices.  See [Catch-Up Bill Run](https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Automate_billing_document_generation/Bill_runs/Z_Catch-Up_Bill_Run) for more information 

## Enum

* `REGULAR` (value: `'Regular'`)

* `CATCHUP` (value: `'CatchUp'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


